agentle.agents.a2a.tasks.task\_state
====================================

.. automodule:: agentle.agents.a2a.tasks.task_state

   
   .. rubric:: Classes

   .. autosummary::
   
      Enum
      TaskState
   